.. -*- rst -*-

Neuroarch
=========

Package Description
-------------------
Neuroarch is a database for codifying knowledge about fruit fly brain circuits.
It defines a hierarchical data model for representation of experimentally
obtained biological data, neural circuit models, and the relationships between
them within a single graph database. Neuroarch provides an Object Graph Mapping
(OGM) that utilizes this data model to enable powerful queries against stored
biological and model data without having to write complex low-level queries.

Authors & Acknowledgements
--------------------------
See the included AUTHORS file for more information.

License
-------
This software is licensed under the `BSD License
<http://www.opensource.org/licenses/bsd-license.php>`_.
See the included LICENSE file for more information.
